@@ -163,7 +163,7 @@ ols_obj_fdf (const gsl_vector * x, void *params,
 
 /* compute variance-covariance matrix */
 gsl_matrix * ols_varcovar(const int o_varcovar,
-			  const gsl_multifit_fdfsolver *s,
+			  gsl_multifit_fdfsolver *s,
 			  const struct objdata obj,
 			  const size_t Pnum){
 
@@ -181,10 +181,22 @@ gsl_matrix * ols_varcovar(const int o_varcovar,
   switch(o_varcovar){
   case 0: /* inverse "reduced Hessian", as in Numerical Recipes */
     {
+
+#ifdef GSL_VER_2
+      gsl_matrix *J = gsl_matrix_alloc(rows, Pnum); 
       
-      gsl_multifit_covar (s->J, 1e-6, covar);
+      gsl_multifit_fdfsolver_jac(s, J); 
+#else
+      gsl_matrix *J = s->J;
+#endif
+
+      gsl_multifit_covar (J, 1e-6, covar);
 
       gsl_matrix_scale (covar,sigma2);
+
+#ifdef GSL_VER_2
+      gsl_matrix_free (J); 
+#endif
       
     }
     break;
